==> gromacs_4.0.7.orig.tar.gz: gromacs-4.0.7/include/types/graph.h <==
/*
 * $Id$
 * 
 *                This source code is part of
 * 
 *                 G   R   O   M   A   C   S
 * 
 *          GROningen MAchine for Chemical Simulations
 * 
 *                        VERSION 3.2.0
 * Written by David van der Spoel, Erik Lindahl, Berk Hess, and others.
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team,
 * check out http://www.gromacs.org for more information.

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * If you want to redistribute modifications, please consider that
 * scientific software is very special. Version control is crucial -
 * bugs must be traceable. We will be happy to consider code for
 * inclusion in the official distribution, but derived work must not
 * be called official GROMACS. Details are found in the README & COPYING
 * files - if they are missing, get the official version at www.gromacs.org.
 * 
 * To help us fund GROMACS development, we humbly ask that you cite
 * the papers on the package - you can find them in the top README file.
 * 
 * For more info, check our website at http://www.gromacs.org
 * 
 * And Hey:
 * GRoups of Organic Molecules in ACtion for Science
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "gmx_fatal.h"

typedef enum { egcolWhite, egcolGrey, egcolBlack, egcolNR } egCol;

typedef struct {
  int      nnodes;	/* The number of nodes				*/
  int      nbound;	/* The number of nodes with edges		*/
  int      start;	/* The first atom in this graph			*/
  int      end;		/* The last atom in this graph			*/
  int      *nedge;	/* For each node the number of edges		*/
  atom_id  **edge;	/* For each node, the actual edges (bidirect.)	*/
  bool     bScrewPBC;   /* Screw boundary conditions                    */
  ivec     *ishift;	/* Shift for each particle              	*/
  int      negc;         
  egCol   *egc;         /* color of each node */
} t_graph;


#define SHIFT_IVEC(g,i) ((g)->ishift[(i)-(g)->start])

==> gromacs_4.5.5.orig.tar.gz: gromacs-4.5.5/include/types/graph.h <==
/*
 * 
 *                This source code is part of
 * 
 *                 G   R   O   M   A   C   S
 * 
 *          GROningen MAchine for Chemical Simulations
 * 
 *                        VERSION 3.2.0
 * Written by David van der Spoel, Erik Lindahl, Berk Hess, and others.
 * Copyright (c) 1991-2000, University of Groningen, The Netherlands.
 * Copyright (c) 2001-2004, The GROMACS development team,
 * check out http://www.gromacs.org for more information.

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * If you want to redistribute modifications, please consider that
 * scientific software is very special. Version control is crucial -
 * bugs must be traceable. We will be happy to consider code for
 * inclusion in the official distribution, but derived work must not
 * be called official GROMACS. Details are found in the README & COPYING
 * files - if they are missing, get the official version at www.gromacs.org.
 * 
 * To help us fund GROMACS development, we humbly ask that you cite
 * the papers on the package - you can find them in the top README file.
 * 
 * For more info, check our website at http://www.gromacs.org
 * 
 * And Hey:
 * GRoups of Organic Molecules in ACtion for Science
 */

#include "idef.h"

#ifdef __cplusplus
extern "C" {
#endif


typedef enum { egcolWhite, egcolGrey, egcolBlack, egcolNR } egCol;

typedef struct {
  int      nnodes;	/* The number of nodes				*/
  int      nbound;	/* The number of nodes with edges		*/
  int      start;	/* The first atom in this graph			*/
  int      end;		/* The last atom in this graph			*/
  int      *nedge;	/* For each node the number of edges		*/
  atom_id  **edge;	/* For each node, the actual edges (bidirect.)	*/
  gmx_bool     bScrewPBC;   /* Screw boundary conditions                    */
  ivec     *ishift;	/* Shift for each particle              	*/
  int      negc;         
  egCol   *egc;         /* color of each node */
} t_graph;


#define SHIFT_IVEC(g,i) ((g)->ishift[(i)-(g)->start])

#ifdef __cplusplus
}
#endif
